@@ -16,7 +16,7 @@ use vars qw($VERSION $AUTOLOAD @ISA $AUTO_ADD);
 
 require 5.008;
 
-$VERSION = '1.46';
+$VERSION = '1.50';
 
 $AUTO_ADD = 0;
 
@@ -993,6 +993,11 @@ sub _handle_start {
     elsif ($self->_start_array_element("skipDays", $el)) {
         # Do nothing - already done in the predicate.
     }
+    elsif ($el eq 'cloud') {
+        if (keys %attribs) {
+            $self->{channel}{cloud} = \%attribs;
+        }
+    }
     elsif ($el eq 'item') {
 
         # deal with trouble makers who use mod_content :)
@@ -1339,10 +1344,20 @@ sub parsefile {
     return $self->_generic_parse("parsefile", $file_to_parse, $options);
 }
 
+sub _untaint {
+    my $self = shift;
+
+    my $value = shift;
+    
+    my ($untainted) = ($value =~ m{(.*)}s);
+
+    return $untainted;
+}
+
 sub _get_save_output_mode {
     my $self = shift;
 
-    return (">:encoding(" . $self->_encoding() . ")");
+    return (">:encoding(" . $self->_untaint($self->_encoding()) . ")");
 }
 
 sub save {
@@ -1633,7 +1648,7 @@ XML::RSS - creates and updates RSS files
 
  while (@{$rss->{'items'}} >= 15)
  {
-     pop(@{$rss->{'items'});
+     pop (@{ $rss->{'items'} });
  }
 
  $rss->add_item(title => "MpegTV Player (mtv) 1.0.9.7",
@@ -1721,9 +1736,18 @@ The default B<mode>
 is append, which adds the item to the end of the list. To insert an item, set the mode
 to B<insert>.
 
-The items are stored in the array @{$obj->{'items'}} where
+The items are stored in the array C<< @{$obj->{'items'}} >> where
 B<$obj> is a reference to an XML::RSS object.
 
+One can specify a category by using the B<'category'> key. B<'category'> can
+point to an array reference of categories:
+
+    $rss->add_item(
+        title => "Foo&Bar",
+        link => "http://www.my.tld/",
+        category => ["OneCat", "TooCat", "3Kitties"],
+    );
+
 =item as_string;
 
 Returns a string containing the RSS for the XML::RSS object.  This
@@ -1758,7 +1782,7 @@ is for B<channel()>.
 
 Parses an RDF Site Summary which is passed into B<parse()> as the first 
 parameter. Returns the instance of the object so one can say 
-C<<$rss->parse($string)->other_method()>>.
+C<< $rss->parse($string)->other_method() >>.
 
 See the add_module() method for instructions on automatically adding
 modules as a string is parsed.
@@ -2012,10 +2036,9 @@ parameter to diff.
 
 =head1 SOURCE AVAILABILITY
 
-The source is available from the perl.org Subversion server:
-
-L<http://svn.perl.org/modules/XML-RSS/>
+The source is available from the GitHub repository:
 
+L<https://github.com/shlomif/perl-XML-RSS>
 
 =head1 AUTHOR
 
